#if !defined(APPLY_MATCH_H)
#define APPLY_MATCH_H

#include <math.h>

   /* multiply by this to convert degrees to radians */
#define DEGTORAD  (M_PI / 180.0)
   /* multiply by this to convert radians to degrees */
#define RADTODEG  (180.0 / M_PI)

#endif   /* APPLY_MATCH_H */
